@@ -1,11 +1,8 @@
-from pysmarthome import RgbLampController, RgbLampsModel
+from pysmarthome import Model, RgbLampController, hex_to_rgb, int_to_hex_color
 import yeelight
 
 class YeelightController(RgbLampController):
-    model_class = RgbLampsModel.clone('YeelightsModel')
-    model_class.schema |= {
-        'addr': { 'type': 'string' },
-    }
+    model_class = Model.extends(RgbLampController.model_class, name='YeelightsModel')
 
 
     def on_load(self, addr='', **data):
@@ -30,18 +27,18 @@ class YeelightController(RgbLampController):
         return int(properties['current_brightness'])
 
 
-    def set_brightness(self):
-        pass
+    def set_brightness(self, val):
+        self.dev.set_brightness(int(val))
 
 
-    def set_color(self):
-        pass
+    def set_color(self, color):
+        if type(color) == str:
+            color = hex_to_rgb(color)
+        self.dev.set_rgb(*color)
 
 
     def get_color(self):
-        properties = self.dev.get_properties()
-        rgb = properties['rgb']
-        return f'#{rgb}'
+        return int_to_hex_color(self.dev.get_properties()['rgb'])
 
 
     def get_power(self):
